package discoverer

import (
	"fmt"
	"net"

	ocdm "git.loafle.net/overflow/commons-go/discovery/model"
	"git.loafle.net/overflow/container_discovery/internal/discoverer/ipv4"
	"git.loafle.net/overflow/container_discovery/internal/discoverer/ipv6"
)

func scanHost(zone *ocdm.Zone, dh *ocdm.DiscoveryHost, resultChan chan interface{}, errChan chan error, doneChan chan<- struct{}, stopChan chan struct{}) {
	defer func() {
		doneChan <- struct{}{}
	}()

	_, ipNet, err := net.ParseCIDR(zone.Network)
	if nil != err {
		errChan <- err
		return
	}
	switch len(ipNet.IP) {
	case net.IPv4len:
		ipv4.ScanHost(zone, dh, resultChan, errChan, stopChan)
	case net.IPv6len:
		ipv6.ScanHost(zone, dh, resultChan, errChan, stopChan)

	default:
		errChan <- fmt.Errorf("Discovery: Not supported ip length")
		return
	}
}
